@@ -86,8 +86,8 @@ def hashivault_list(params):
             secret = '/'.join(listo[1:])
     # for backwards compatibiltiy with old hashivault_list module
     if secret.startswith('metadata/'):
+        secret = secret.replace('metadata/', '', 1)
         version = 2
-        secret = secret.lstrip('metadata/')
         metadata = True
     else:
         metadata = False
